@@ -1,9 +1,9 @@
 package Music::Duration;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Add 32nd, 64th and tuplet durations to MIDI-Perl
+# ABSTRACT: Add 32nd, 64th, 128th and tuplet durations to MIDI-Perl
 
-our $VERSION = '0.0605';
+our $VERSION = '0.0700';
 use strict;
 use warnings;
 
@@ -14,8 +14,8 @@ use MIDI::Simple;
     # Set the initial duration to one below 32nd,
     my $last = 's'; # ..which is a sixteenth.
 
-    # Add 32nd and 64th as y and x.
-    for my $duration ( qw( y x ) ) {
+    # Add 32nd, 64th and 128th as y, x, and o respectively.
+    for my $duration ( qw( y x o ) ) {
         # Create a MIDI::Simple format note identifier.
         my $n = $duration . 'n';
 
@@ -23,7 +23,7 @@ use MIDI::Simple;
         $MIDI::Simple::Length{$n} = $MIDI::Simple::Length{ $last . 'n' } / 2;
 
         # Compute the dotted duration.
-        $MIDI::Simple::Length{ 'd'  . $n } = $MIDI::Simple::Length{$n}
+        $MIDI::Simple::Length{ 'd' . $n } = $MIDI::Simple::Length{$n}
             + $MIDI::Simple::Length{$n} / 2;
 
         # Compute the double-dotted duration.
@@ -31,7 +31,7 @@ use MIDI::Simple;
             + $MIDI::Simple::Length{$n} / 4;
 
         # Compute the triplet duration.
-        $MIDI::Simple::Length{ 't'  . $n } = $MIDI::Simple::Length{$n} / 3 * 2;
+        $MIDI::Simple::Length{ 't' . $n } = $MIDI::Simple::Length{$n} / 3 * 2;
 
         # Increment the last duration seen.
         $last = $duration;
@@ -57,11 +57,11 @@ __END__
 
 =head1 NAME
 
-Music::Duration - Add 32nd, 64th and tuplet durations to MIDI-Perl
+Music::Duration - Add 32nd, 64th, 128th and tuplet durations to MIDI-Perl
 
 =head1 VERSION
 
-version 0.0605
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -81,9 +81,9 @@ version 0.0605
 
 =head1 DESCRIPTION
 
-This module adds thirty-second and sixty-fourth note divisions to
-L<MIDI::Simple> C<%Length>.  It also adds fractional note divisions with the
-B<tuplet()> function.
+This module adds 32nd, 64th, and 128th note divisions to
+L<MIDI::Simple> C<%Length>.  It also adds fractional note divisions
+with the B<tuplet()> function.
 
 32nd durations added:
 
@@ -99,25 +99,34 @@ B<tuplet()> function.
   ddxn: double dotted sixty-fourth note
   txn:  sixty-fourth note triplet
 
+128th durations added:
+
+  on:   128th note
+  don:  dotted 128th note
+  ddon: double dotted 128th note
+  ton:  128th note triplet
+
 =head1 FUNCTION
 
 =head2 tuplet()
 
   Music::Duration::tuplet( 'qn', 'z', 5 );
   # $score->n( 'zqn', ... );
+
   Music::Duration::tuplet( 'wn', 'z', 7 );
   # $score->n( 'zwn', ... );
 
-Add a fractional division to the L<MIDI::Simple> C<Length> hash for a given
-B<name> and B<duration>.
+Add a fractional division to the L<MIDI::Simple> C<Length> hash for a
+given B<name> and B<duration>.
 
-Musically, this creates a series of notes in place of the given B<duration>.
+Musically, this creates a series of notes in place of the given
+B<duration>.
 
 A triplet is a 3-tuplet.
 
-So in the first example, instead of a quarter note, we instead play 5 beats - a
-5-tuple.  In the second, instead of a whole note (of four beats), we instead
-play 7 beats.
+So in the first example, instead of a quarter note, we instead play 5
+beats - a 5-tuple.  In the second, instead of a whole note (of four
+beats), we instead play 7 beats.
 
 =head2 tuple()
 
